#!/bin/bash
#
# SCHED visibility check script v6.26
#
###############################################
#                   INPUT                     #
###############################################
NUMBER_OF_THREADS=12
# don't change anything below this line unless you know what you are doing
STATIONS_DAT_FILE="stations.dat"


## This function will set the random session key in attempt to avoid 
## file collisions if other instances of the script are running at the same time.
function set_session_key {
 if [ -r /dev/urandom ];then
  local RANDOMFILE=/dev/urandom
 elif [ -r /dev/random ];then  
  local RANDOMFILE=/dev/random
 else
  echo "ERROR: cannot find /dev/random" >> /dev/stderr
  local RANDOMFILE=""
 fi
 if [ "$RANDOMFILE" != "" ];then
  local SESSION_KEY="$$"_`tr -cd a-zA-Z0-9 < $RANDOMFILE | head -c 12`
 else
  local SESSION_KEY="$$"
 fi
 echo "$SESSION_KEY"
}


############# INITIAL VARIABLES #############
# Set session key
export SESSION_KEY=$(set_session_key) # or SESSION_KEY=`set_session_key`        
#
INPUT_OK=0
DETAILED_VISIBILITY_PROFILE=/tmp/autosched_detailed_visibility_profile_$SESSION_KEY.txt
REAL_PATH=`readlink -f $0`
REAL_PATH=`dirname $REAL_PATH`

#export RESULTS_DIR=/tmp/autosched_"$$"_`tr -cd a-zA-Z0-9 < /dev/urandom | head -c 12 ; echo ""`_results
export RESULTS_DIR=/tmp/autosched_"$SESSION_KEY"_results
if [ ! -d $RESULTS_DIR ];then
 mkdir $RESULTS_DIR
else
 export RESULTS_DIR=/tmp/autosched_"$SESSION_KEY"_"$SESSION_KEY"_results
 if [ ! -d $RESULTS_DIR ];then
  mkdir $RESULTS_DIR
 else
  echo "WARNING! WARNING! WARNING! The resultd directory $RESULTS_DIR already exists! This is not supposed to happen!" >> /dev/stderr
 fi
fi
#############################################

function_to_fork() {
############ Change to a temporary directory ############
FORKED_SESSION_KEY=$(set_session_key)
#WORK_DIR=/tmp/autosched_"$$"_`tr -cd a-zA-Z0-9 < /dev/urandom | head -c 12 ; echo ""`
WORK_DIR=/tmp/autosched_"$FORKED_SESSION_KEY"
if [ -d $WORK_DIR ];then
 echo "ERROR: the temporary directory $WORK_DIR already exists ! Something is seriously messed up here!"
 exit 1
fi
mkdir $WORK_DIR
cd $WORK_DIR   
if [ $? -ne 0 ];then
 echo "ERROR: cannot change to the temporary directory $WORK_DIR ! Something is seriously messed up here!"
 exit 1
fi

echo "! SCHED visibility test
! ================================================================ 
! Control Information 
! ================================================================ 
overwrite ! Prevents need to clean out old files on restart. 
autotape = -1 ! Automatic tape allocation on 2 drive stations. 
minpause = 0 ! Minimum playback disk stop duration 
prestart = 0 ! Start disks this long before scan start 
sumitem = early, dwell, tpstart, el1 ! Control items in summary file. 
 
! ================================================================ 
! Cover information (PI, experiment, etc.) 
! ================================================================ 
version = 1.0 
expt = 'RadioAstron AGN ESP fringe survey' 
expcode = 're00xx' 
piname = 'Yuri Kovalev' 
address1 = 'ASC Lebedev' 
address2 = 'Profsoyuznaya 84/32' 
address3 = '117997 Moscow, Russia' 
email = 'kirx@scan.sai.msu.ru' 
phone = '+7-495-3332167' 
obsphone = '+7-915-1546281, +7-903-6614865' 
fax = '+7-495-3332378' 
obsmode = 'L/C-band, dual-pol' 
obstype = 'VLBA' 
note1 = 'L/C-band, Radioastron-compatible frequency setup' 
note2 = 'P-CAL is ON' 
note3 = '' 
note4 = '' 
 
! ================================================================ 
! Correlator section 
! ================================================================ 
correl = 'ASC' 
coravg = 1 
corchan = 32 
cornant = 6 
corpol = 'on' 
corwtfn = 'uniform' 
corsrcs = 'schedule' 
cortape = 'ftp' 
corship1 = '' 
corship2 = '' 
corship3 = '' 
cornote1 = '' 
 
! ================================================================ 
! Catalogs. These are the standard ones and are the defalts. 
! ================================================================ 
srcfile = '$SCHED/catalogs/sources.vlba' 
 
!stafile = '$SCHED/catalogs/stations.dat' 
stafile = './stations.dat' 
!stafile = '$REAL_PATH/$STATIONS_DAT_FILE' 
 
locfile = '$SCHED/catalogs/locations.dat' 
!locfile = './locations.dat' 
 
freqfile = '$SCHED/catalogs/freq.dat' 
!freqfile = './freq.dat' 
 
! ================================================================ 
! Frequency setups 
! ================================================================ 

! ---*** 6cm frequency setup ***--- 
SETINI=ra6cm2.set /
  BAND='6CM'
  NCHAN=4
  BITS=2
  BBFILTER=16.0
  NETSIDE = L,L,U,U
! **** The RadioAstron formatter mode is $RADIOASTRON_FORMATTER_MODE - this determines the sky frequency ****
  FREQREF = $FREQREF_C
  POL=dual
  PCAL  = '$PCAL_MHZ'
!  NOISE = '$NOISE_DIODE'
  BARREL=ROLL_OFF
  /
 !--------------------------------------------------------------------------
 ! LBA stations setup should _always_ go first, otherwise it will be corrupted by other station's settings
  station   = MOPRA, ATCA, HOBART, PARKES, CEDUNA
   bbc      = 1, 1, 2, 2
   pol      = rcp, rcp, lcp, lcp
   netside  = L, U, L, U
   /
 !--------------------------------------------------------------------------
   firstlo=4500,4500,4500,4500
   ifchan  =  A,   B,   A,   B
   bbc     =  1,   9,   1,   9
   netside = U, U, L, L
   POL= RCP, LCP, RCP, LCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B  station  =  SVETLOE, ZELENCHK, BADARY /
 !--------------------------------------------------------------------------
   firstlo= 4240,4240,4240,4240
   ifchan  =   A,   C,   A,   C
   bbc     =   1,   5,   1,   5
   netside = U, U, L, L
   POL= RCP, LCP, RCP, LCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   station  =  EFLSBERG /
!--------------------------------------------------------------------------
   firstlo= 22500,22500,22500,22500
   ifchan  =   A,  B,  A,  B
   bbc    =    1,   5,   1,   5
   netside = U, U, L, L
   POL= RCP, LCP, RCP, LCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   station  =  SHAO-65 /                                                   
 !--------------------------------------------------------------------------
   firstlo= 4700,4700,4700,4700
   ifchan =  '2N','1N','2N','1N'
   bbc    =    2,   1,   2,   1
   netside = U, U, L, L
   POL= LCP, RCP, LCP, RCP     ! Reverse polarization order in WSTRBORK!
   station= WSTRBORK /
!--------------------------------------------------------------------------
   firstlo= 4158,4158,4158,4158
   ifchan  =   A,   C,   A,   C
   bbc    =    1,   2,   1,   2
   netside = U, U, L, L
   POL= RCP, LCP, RCP, LCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   station  =  YEBES40M /
!--------------------------------------------------------------------------
   firstlo= 4200,4200,4200,4200                                                                                              
   ifchan  =  A1,  B1,  A1,  B1                                                                                              
   bbc     =   1,   5,   1,   5                                                                                              
  format = MARK5B   station  =  IRBENE /                                                                                     
! 
!--------------------------------------------------------------------------
! Warning! The frequency setup for Ev is a fake! It is up to Ev staff to manually set correct parameters.
   firstlo=4500,4500,4500,4500
   ifchan  =  A,  A,  B,  B
   bbc     =  1,  1,  2,  2
   netside = U, L, U, L
   POL= LCP, LCP, RCP, RCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   ! Actually, EVPATORI records in the RDR format that is converted to MARK5B for use with DiFX.
  station  =  EVPATORI /
!--------------------------------------------------------------------------
! Warning! The frequency setup for Kl is a fake! It is up to Kl staff to manually set correct parameters.
   firstlo=4500,4500,4500,4500
   ifchan  =  A,  A,  B,  B
   bbc     =  1,  1,  2,  2
   netside = U, L, U, L
   POL= LCP, LCP, RCP, RCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   ! Actually, EVPATORI records in the RDR format that is converted to MARK5B for use with DiFX.
  station  =  KALYAZIN /
!--------------------------------------------------------------------------
! Warning! The frequency setup for Ud is a fake! It is up to Ud staff to manually set correct parameters.
   firstlo= 4240,4240,4240,4240
   ifchan  =   A,   A,   C,   C
   bbc     =   1,   1,   5,   5
   netside = U, L, U, L
   POL= LCP, LCP, RCP, RCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   station  =  USUDARA /
 !--------------------------------------------------------------------------
!
ENDSET
/

! ---*** 1.35cm frequency setup ***---
SETINI = ra1cm2.set /
  BAND='1CM'
  NCHAN=4
  BITS=2
  BBFILTER=16.0
! **** The RadioAstron formatter mode is $RADIOASTRON_FORMATTER_MODE - this determines the sky frequency ****
  FREQREF = $FREQREF_K
  FREQOFF = 0.00, 0.00, 0.00, 0.00
!  netside = L, L, U, U
$NETSIDE_LINE
  POL=dual
  PCAL  = '$PCAL_MHZ'
!  NOISE = '$NOISE_DIODE'
  BARREL=ROLL_OFF
/
 !--------------------------------------------------------------------------
 ! LBA stations setup should _always_ go first, otherwise it will be corrupted by other station's settings
  station   = MOPRA, ATCA, HOBART, PARKES, CEDUNA 
   bbc      = 1, 1, 2, 2
   pol      = rcp, rcp, lcp, lcp
   netside  = L, U, L, U
   /
 !--------------------------------------------------------------------------
 ! The TORUN K-band frequency setup is experimental! Needs to be checked!
   firstlo=21500,21500,21500,21500
   ifchan  =  C,  A,  C,  A
   bbc     =  1,  2,  1,  2
   NETSIDE = L, L, U, U
   POL= RCP, LCP, RCP, LCP
  format = MKIV   station  =  TORUN /
!--------------------------------------------------------------------------
   firstlo= 21920,21920,21920,21920
   ifchan  =    A,    B,    A,    B
   bbc     =    1,    9,    1,    9
   netside = U, U, L, L
   POL= RCP, LCP, RCP, LCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   station  =  SVETLOE, ZELENCHK, BADARY /
!--------------------------------------------------------------------------
   firstlo=21500,21500,21500,21500
   ifchan  =   A,   C,   A,   C
   bbc     =   1,   5,   1,   5
   netside = U, U, L, L
   POL= RCP, LCP, RCP, LCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   station  =  EFLSBERG /
!--------------------------------------------------------------------------
   firstlo= 21550,21550,21550,21550
   ifchan  =   A,   C,   A,   C
   bbc    =    1,   2,   1,   2
   netside = U, U, L, L
   POL= RCP, LCP, RCP, LCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   station  =  YEBES40M /
!--------------------------------------------------------------------------
! Warning! The frequency setup for Ev is a fake! It is up to Ev staff to manually set correct parameters.
   firstlo=21500,21500,21500,21500
   ifchan  =  A,  A,  B,  B
   bbc     =  1,  1,  2,  2
   netside = U, L, U, L
   POL= LCP, LCP, RCP, RCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   ! Actually, EVPATORI records in the RDR format that is converted to MARK5B for use with DiFX.
  station  =  EVPATORI /
 !--------------------------------------------------------------------------
! Warning! The frequency setup for Kl is a fake! It is up to Kl staff to manually set correct parameters.
   firstlo=21500,21500,21500,21500
   ifchan  =  A,  A,  B,  B
   bbc     =  1,  1,  2,  2
   netside = U, L, U, L
   POL= LCP, LCP, RCP, RCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   ! Actually, KALYAZIN records in the RDR format that is converted to MARK5B for use with DiFX.
  station  =  KALYAZIN /
 !--------------------------------------------------------------------------
 !--------------------------------------------------------------------------
! Warning! The frequency setup for the KVN is a fake! 
   firstlo=21500,21500,21500,21500
   ifchan  =  A,  A,  B,  B
   bbc     =  1,  1,  2,  2
   netside = U, L, U, L
   POL= LCP, LCP, RCP, RCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   ! Actually, KALYAZIN records in the RDR format that is converted to MARK5B for use with DiFX.
  station  =  KVNYS, KVNUS, KVNTN /
 !--------------------------------------------------------------------------
ENDSET
/

! ---*** 18cm setup ***---
SETINI=ra18cm2.set /
  BAND='18CM'
  NCHAN=4
  BITS=2
  BBFILTER=16.0
  NETSIDE = L,L,U,U
! **** The RadioAstron formatter mode is $RADIOASTRON_FORMATTER_MODE - this determines the sky frequency ****
  FREQREF = $FREQREF_L
  POL=dual
  $AUTOLEVEL
  PCAL     = '$PCAL_MHZ'
  NOISE = '$NOISE_DIODE'
  BARREL=ROLL_OFF
  /
 !--------------------------------------------------------------------------
 ! LBA stations setup should _always_ go first, otherwise it will be corrupted by other station's settings
  station   = MOPRA, ATCA, HOBART, PARKES, CEDUNA, WW_LBA, ASKAP 
   ! WARNING! THIS IS A FAKE
   firstlo=1260,1260,1260,1260
   ! WARNING! THIS IS A FAKE
   ifchan  =  A,   A,   B,   B
   ! The following lines are Ok
   bbc      = 1, 1, 2, 2
   pol      = rcp, rcp, lcp, lcp
   netside  = L, U, L, U
   /
!--------------------------------------------------------------------------
   firstlo=1260,1260,1260,1260
   ifchan  =  A,   B,   A,   B
   bbc     =  1,   9,   1,   9
   netside = U, U, L, L
   POL= RCP, LCP, RCP, LCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   station  =  SVETLOE, ZELENCHK, BADARY /
!--------------------------------------------------------------------------
   firstlo=1490,1490,1490,1490
   ifchan=    B,   D,   B,   D
   bbc=       1,   5,   1,   5
   netside = U, U, L, L
   POL= RCP, LCP, RCP, LCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   station  =  EFLSBERG /
!--------------------------------------------------------------------------
   firstlo=1510,1510,1510,1510
   ifchan= '2N', '1N', '2N', '1N'
   bbc    =    2,   1,   2,   1
   netside = U, U, L, L
   POL= LCP, RCP, LCP, RCP     ! Reverse polarization order in WSTRBORK!
   station= WSTRBORK /
!
   firstlo= 2324,2324,2324,2324
   ifchan =   A2,  B2,  A2,  B2
   bbc =       1,   5,   1,   5
  format = MARK5B   station  =  SARDINIA /
!
!--------------------------------------------------------------------------
! Warning! The frequency setup for Ev is a fake! It is up to Ev staff to manually set correct parameters.
   firstlo=1490,1490,1490,1490
   ifchan  =  A,  A,  B,  B
   bbc     =  1,  1,  2,  2
   netside = U, L, U, L
   POL= LCP, LCP, RCP, RCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   ! Actually, EVPATORI records in the RDR format that is converted to MARK5B for use with DiFX.
  station  =  EVPATORI /
!--------------------------------------------------------------------------
! Warning! The frequency setup for Kl is a fake! It is up to Kl staff to manually set correct parameters.
   firstlo=1490,1490,1490,1490
   ifchan  =  A,  A,  B,  B
   bbc     =  1,  1,  2,  2
   netside = U, L, U, L
   POL= LCP, LCP, RCP, RCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   ! Actually, KALYAZIN records in the RDR format that is converted to MARK5B for use with DiFX.
  station  =  KALYAZIN /
!--------------------------------------------------------------------------
! Warning! The frequency setup for Ud is a fake! It is up to Ud staff to manually set correct parameters.
   firstlo=1490,1490,1490,1490
   ifchan=    B,   B,   D,   D
   bbc=       1,   1,   5,   5
   netside = U, L, U, L
   POL= LCP, LCP, RCP, RCP     ! We specify it here explicitly, so it will not be corrupted
                               ! if a previous telescope had a different polarization setup.
  format = MARK5B   station  =  USUDARA /
 !--------------------------------------------------------------------------
ENDSET
/

! ================================================================
!       In line source catalog.
! ================================================================
srccat /

! ---***### User-defined sources ###***---
! The target source has to be listed in $SCHED/catalogs/sources.vlba
! or in the list below in order for SCHED to recognize it.
!
!-----------------------------------
!  Radioastron Input Catalog v048  !
!-----------------------------------
!
! If you would like to change something in this catalog
! please contact Alexander Pushkarev <contour@mail.ru>
!
! ----****#### FAKE source ####****----
   source='HOME'  RA=00:00:00.00  DEC=+88:00:00.0  equinox='J2000' rem='fake source representing RadioAstron home position for tests' /
! RA-AO4-01
   source='ORIONH2O', 'ORION_H2O'  RA=05:35:14.1255  DEC=-05:22:36.475  equinox='J2000' rem='H2O maser; position from 2011ApJ739L..59H, RA-AO4-01, RA-AO2-08' /
   source='W49N_H2O'   RA=19:10:13.426   DEC=+09:06:12.38   equinox='J2000' rem='H2O maser; positions from 2000ApJS...129Argon, RA-AO4-01, RA-AO2-13' /
   source='CPHW2H2O', 'CEP_HW2_H2O', 'CEPHEUS_A_HW2_H2O'  RA=22:56:17.9779  DEC=62:01:49.4421  equinox='J2000' rem='H2O maser; positions from 2003ApJ586...306Gallimore, RA-AO4-01, RA-AO2-08' /
! RA-AO4-02   
   source='B0740-28', 'J0742-2822' RA=07:42:49.058   DEC=-28:22:43.76   equinox='J2000' rem='RA-AO4-02' /
   source='B0818-13', 'J0820-1350' RA=08:20:26.382   DEC=-13:50:55.859  equinox='J2000' rem='RA-AO4-02' /
   source='B0823+26', 'J0826+2637' RA=08:26:51.3833  DEC=+26:37:23.790  equinox='J2000' rem='PSR Low dispersed DM=19.454, RA-AO4-02, RA-AO2-06' /
   source='B0835-41', 'J0837-4135' RA=08:37:21:182   DEC=-41:35:14.370  equinox='J2000' rem='RA-AO4-02' /
   source='B1240-64', 'J1243-6423' RA=12:43:17.158   DEC=-64:23:23.850  equinox='J2000' rem='RA-AO4-02' /
   source='B1323-58', 'J1326-5859' RA=13:26:58.270   DEC=-58:59:29.100  equinox='J2000' rem='RA-AO4-02' /
   source='B1323-62', 'J1327-6222' RA=13:27:17.400   DEC=-62:22:44.600  equinox='J2000' rem='RA-AO4-02' /
   source='B1426-66', 'J1430-6623' RA=14:30:40.872   DEC=-66:23:05.040  equinox='J2000' rem='RA-AO4-02' /
   source='B1429-64'               RA=14:53:32.737   DEC=-64:13:15.590  equinox='J2000' rem='RA-AO4-02' /
   source='B1642-03', 'J1645-0317' RA=16:45:02.0414  DEC=-03:17:58.320  equinox='J2000' rem='PSR High dispersed DM=35.727, RA-AO4-02, RA-AO2-01, RA-AO2-06' /
   source='B1727-47', 'J1731-4744' RA=17:31:42.103   DEC=-47:44:34.560  equinox='J2000' rem='RA-AO4-02' /
   source='B1831-03', 'J1833-0338' RA=18:33:41.914   DEC=-03:39:04.33   equinox='J2000' rem='RA-AO4-02' /
   source='B1839+56', 'J1840+5640' RA=18:40:44.608   DEC=+56:40:55.47   equinox='J2000' rem='RA-AO4-02' /
   source='B1859+03', 'J1901+0331' RA=19:01:31.781   DEC=+03:31:05.92   equinox='J2000' rem='PSR DM=402.080, position from 2004MNRAS.353.1311H, RA-AO4-02, RA-AO2-01' /
   source='B1911-04', 'J1913-0440' RA=19:13:54.173   DEC=-04:40:47.68   equinox='J2000' rem='RA-AO4-02' /
   source='B1937+21', 'J1939+2134' RA=19:39:38.550   DEC=+21:34:59.100  equinox='J2000' rem='PSR GP,High dispersed DM=71.0398, RA-AO4-02' /
   source='B2016+28', 'J2018+2839' RA=20:18:03.8333  DEC=+28:39:54.212  equinox='J2000' rem='PSR Low dispersed DM=14.172, RA-AO4-02, RA-AO2-06' /
   source='B2021+51', 'J2022+5154' RA=20:22:49.873   DEC=+51:54:50.233  equinox='J2000' rem='PSR High dispersed DM=22.648, RA-AO4-02' /
   source='B2255+58', 'J2257+5909' RA=22:57:57.744   DEC=+59:09:14.83   equinox='J2000' rem='RA-AO4-02' /
   source='B2319+60', 'J2321+6024' RA=23:21:55.213   DEC=+60:24:30.71   equinox='J2000' rem='RA-AO4-02' /
! RA-AO4-03
   source='0201+113', 'J0203+1134' RA=02:03:46.657061 DEC=+11:34:45.40942 equinox='J2000' rem='AGN, HIGHz, rfc_2013d Petrov, 2013, unpublished 18135 observations, RA-AO4-03, RA-AO3-04, RA-AO2-03, RA-AO2-12' /  
   source='1713+218', 'J1715+2145' RA=17:15:21.257012 DEC=+21:45:31.70121 equinox='J2000' rem='AGN, HIGHz, rfc_2013d Petrov, 2013, unpublished 50 observations, RA-AO4-03, RA-AO2-03' /
   source='1937-101', 'J1939-1002' RA=19:39:57.256582 DEC=-10:02:41.52079 equinox='J2000' rem='AGN, HIGHz, rfc_2013d Petrov, 2013, RA-AO4-03' /
   source='2000-330', 'J2003-3251' RA=20:03:24.116342 DEC=-32:51:45.13295 equinox='J2000' rem='AGN, HIGHz, rfc_2013d Petrov, 2013, RA-AO4-03' /
   source='2215+020', 'J2217+0220' RA=22:17:48.237927 DEC=+02:20:10.71214 equinox='J2000' rem='AGN, HIGHz, rfc_2013d Petrov, 2013, unpublished 383 observations, RA-AO4-03, RA-AO3-04, RA-AO3-03, RA-AO2-03, RA-AO2-12' /
! RA-AO4-04
   source='0316+413', 'J0319+4130', '3C84' RA=03:19:48.160114 DEC=+41:30:42.10559 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 15448 observations, RA-AO4-04, RA-AO3-04, RA-AO2-12' /
! RA-AO4-05
   source='M33-IC13',  'M33-IC133'   RA=01:33:16.545   DEC=30:52:50.0     equinox='J2000' rem='RA-AO4-05' /
   source='LMC-N113',   'N113_H2O'   RA=05:13:25.15    DEC=-69:22:45.4    equinox='J2000' rem='H2O maser; positions from 2010MNRAS404..779Ellingsen, RA-AO4-05, RA-AO3-10, RA-AO2-13'/
   source='NGC3079', 'NGC3079_H2O'   RA=10:01:57.802   DEC=55:40:47.26    equinox='J2000' rem='H2O maser; positions from 2005ApJ...618K, RA-AO4-05, RA-AO3-10, RA-AO2-13' /
   source='NGC4258', 'NGC4258_H2O'   RA=12:18:57.5046  DEC=47:18:14.303   equinox='J2000' rem='H2O maser; positions from Herrnstein et al. 2005, RA-AO4-05, RA-AO3-10, RA-AO2-13' /
   source='NGC4945'                  RA=13:05:27.484   DEC=-49:28:05.37   equinox='J2000' rem='H2O extragal maser; position from the RA proposal, RA-AO4-05, RA-AO3-10' /
   source='CIRCINUS', 'CIRCINUS_H2O' RA=14:13:09.95    DEC=-65:20:21.2    equinox='J2000' rem='H2O maser; positions from ApJ2003590...162Greenhill, RA-AO4-05, RA-AO3-10, RA-AO2-13'/
! RA-AO4-06
   source='0851+202', 'J0854+2006', 'OJ287' RA=08:54:48.874930 DEC=+20:06:30.64078 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 213710 observations, RA-AO4-06, RA-AO3-04, RA-AO3-05, RA-AO2-12' /
   source='2251+158', 'J2253+1608', '3C454.3' RA=22:53:57.747940 DEC=+16:08:53.56074 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 40570 observations, RA-AO4-06, RA-AO3-04, RA-AO2-12' /
   source='2230+114', 'J2232+1143', 'CTA102' RA=22:32:36.408905 DEC=+11:43:50.90395 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 5100 observations, RA-AO4-06, RA-AO3-04, RA-AO2-12' /
! RA-AO4-07
   source='0048-097', 'J0050-0929' RA=00:50:41.317387 DEC=-09:29:05.21037 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 46175 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0234+285', 'J0237+2848' RA=02:37:52.405678 DEC=+28:48:08.98999 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 57147 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0235+164', 'J0238+1636' RA=02:38:38.930107 DEC=+16:36:59.27452 equinox='J2000' rem='AGN, IDV, rfc_2013d Petrov, 2013, unpublished 65224 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0430+052', 'J0433+0521', '3C120' RA=04:33:11.095533 DEC=+05:21:15.61916 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 9633 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0454-234', 'J0457-2324' RA=04:57:03.179228 DEC=-23:24:52.02024 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 69420 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0529+483', 'J0533+4822' RA=05:33:15.865793 DEC=+48:22:52.80771 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 19801 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0607-157', 'J0609-1542' RA=06:09:40.949536 DEC=-15:42:40.67271 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 40739 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0648-165', 'J0650-1637' RA=06:50:24.581861 DEC=-16:37:39.72548 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 10699 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0716+714', 'J0721+7120' RA=07:21:53.448474 DEC=+71:20:36.36340 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 42370 observations, RA-AO4-07, RA-AO3-04, RA-AO2-10, RA-AO2-12' /
   source='0727-115', 'J0730-1141' RA=07:30:19.112473 DEC=-11:41:12.60063 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 155894 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0814+425', 'J0818+4222' RA=08:18:15.999600 DEC=+42:22:45.41481 equinox='J2000' rem='AGN, MASIV, rfc_2013d Petrov, 2013, unpublished 3620 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0823+033', 'J0825+0309' RA=08:25:50.338355 DEC=+03:09:24.51995 equinox='J2000' rem='AGN, MASIV, rfc_2013d Petrov, 2013, unpublished 57025 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='0827+243', 'J0830+2410' RA=08:30:52.086193 DEC=+24:10:59.82026 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 3847 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
!   source='0851+202', 'J0854+2006', 'OJ287' RA=08:54:48.874930 DEC=+20:06:30.64078 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 213710 observations, RA-AO4-07, RA-AO3-04, RA-AO3-05, RA-AO2-12' /
   source='0954+658', 'J0958+6533' RA=09:58:47.245116 DEC=+65:33:54.81801 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 13350 observations, fringe-finder for M81 RA-AO4-07, RA-AO3-04, RA-AO3-07, RA-AO2-12' /
   source='1005+066', 'J1008+0621' RA=10:08:00.816157 DEC=+06:21:21.21593 equinox='J2000' rem='AGN, MASIV, rfc_2013d Petrov, 2013, unpublished 317 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='1040+244', 'J1043+2408' RA=10:43:09.035778 DEC=+24:08:35.40933 equinox='J2000' rem='AGN, MASIV, rfc_2013d Petrov, 2013, unpublished 7417 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='1044+719', 'J1048+7143' RA=10:48:27.619927 DEC=+71:43:35.93838 equinox='J2000' rem='AGN, MASIV, rfc_2013d Petrov, 2013, unpublished 141793 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='1101+384', 'J1104+3812', 'MRK421' RA=11:04:27.313945 DEC=+38:12:31.79894 equinox='J2000' rem='AGN, MASIV, rfc_2013d Petrov, 2013, unpublished 17168 observations, RA-AO4-07, RA-AO3-04, RA-AO3-09, RA-AO2-12' /
   source='1222+216', 'J1224+2122' RA=12:24:54.458394 DEC=+21:22:46.38857 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 406 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='1226+023', 'J1229+0203', '3C273B', '3C273' RA=12:29:06.699731 DEC=+02:03:08.59797 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 32011 observations, RA-AO4-07, RA-AO3-04, RA-AO3-05, RA-AO2-12,  RA-AO2-18' /
   source='1253-055', 'J1256-0547', '3C279' RA=12:56:11.166557 DEC=-05:47:21.52489 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 7924 observations, RA-AO4-07, RA-AO3-04, RA-AO3-05, RA-AO2-12,  RA-AO2-18' /
   source='1357+769', 'J1357+7643' RA=13:57:55.371538 DEC=+76:43:21.05098 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 226762 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
   source='1641+399', 'J1642+3948', '3C345' RA=16:42:58.809963 DEC=+39:48:36.99385 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 51938 observations, RA-AO4-07, RA-AO3-04, RA-AO3-05, RA-AO2-10, RA-AO2-12' /
   source='1642+690', 'J1642+6856' RA=16:42:07.848507 DEC=+68:56:39.75636 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 18956 observations, RA-AO4-07, RA-AO3-04, RA-AO2-11, RA-AO2-12' /
   source='2200+420', 'J2202+4216', 'BLLAC' RA=22:02:43.291371 DEC=+42:16:39.97987 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 59417 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
!   source='2230+114', 'J2232+1143', 'CTA102' RA=22:32:36.408905 DEC=+11:43:50.90395 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 5100 observations, RA-AO4-07, RA-AO3-04, RA-AO2-12' /
! RA-AO4-08
   source='0615+820', 'J0626+8202'         RA=06:26:03.006221 DEC=+82:02:25.56790 equinox='J2000' rem='AGN, rfc_2013d Petrov, 201d, RA-AO4-09' /
! RA-AO4-09
   source='NGC1052', 'J0241-0815'          RA=02:41:04.798502 DEC=-08:15:20.75192 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, RA-AO4-09' /
! RA-AO4-11 not supported proposal
!   source='NML_CYG', 'NML_CYG_H2O'         RA=20:46:25.543   DEC=40:06:59.42    equinox='J2000' rem='OH maser; positions from 2008PASJ60...1069NAGAYAMA, RA-AO4-11, RA-AO2-13' /
!   source='VX_SGR_H2O'                     RA=18:08:04.04831 DEC=-22:13:26.6327 equinox='J2000' rem='H2O maser; positions from Simbad, RA-AO4-11, RA-AO2-13'/
!   source='PZ_CAS'                         RA=23:44:03.28104 DEC=+61:47:22.1823 equinox='J2000' rem='RA-AO4-11' /
!   source='IRAS1510', 'IRAS15103-5754_H2O' RA=15:14:18.400   DEC=-58:05:21.0    equinox='J2000' rem='H2O WF maser; positions from Simbad, RA-AO4-11, RA-AO2-13'/
!   source='IRAS1811', 'IRAS18113-2503_H2O' RA=18:14:26.740   DEC=-25:02:54.80   equinox='J2000' rem='H2O WF maser; positions from 2011ApJL739..L14Gomez, RA-AO4-11, RA-AO2-13'/
!   source='IRAS1828', 'IRAS18286-0959_H2O' RA=18:31:22.934   DEC=-09:57:21.70   equinox='J2000' rem='H2O WF maser; positions from 2013PASJ65..28Imai, RA-AO4-11' /
!   source='W43A_H2O'                       RA=18:47:41.166   DEC=-01:45:11.7    equinox='J2000' rem='H2O WF maser; positions from 2006ApJ648..L59Vlemmings, RA-AO4-11, RA-AO2-13'/
! RA-AO4-12
!   source='B0823+26', 'J0826+2637' RA=08:26:51.383300 DEC=+26:37:23.79000 equinox='J2000' rem='PSR Low dispersed DM=19.454, RA-AO4-12, RA-AO2-06' /
!   source='0827+243', 'J0830+2410' RA=08:30:52.086193 DEC=+24:10:59.82026 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 3847 observations, RA-AO4-12, RA-AO3-04, RA-AO2-12' /
!   source='B1839+56'               RA=18:40:44.608    DEC=+56:40:55.47    equinox='J2000' rem='RA-AO4-12' /
   source='1823+568', 'J1824+5651' RA=18:24:07.068371 DEC=+56:51:01.49076 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 8126 observations, RA-AO4-12, RA-AO3-04, RA-AO2-12' /
!   source='B2021+51', 'J2022+5154' RA=20:22:49.873000 DEC=+51:54:50.23300 equinox='J2000' rem='PSR High dispersed DM=22.648, RA-AO4-12' /
   source='2037+511', 'J2038+5119', '3C418' RA=20:38:37.034732 DEC=+51:19:12.66253 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 108656 observations, RA-AO4-12, RA-AO3-04, RA-AO2-12' /
   source='2022+542', 'J2023+5427' RA=20:23:55.844020 DEC=+54:27:35.82889 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 140 observations, RA-AO4-12, RA-AO3-04, RA-AO2-12' /
   source='B2154+40'               RA=21:57:01.8495   DEC=+40:17:45.986   equinox='J2000' rem='RA-AO4-12' /
!   source='2200+420', 'J2202+4216', 'BLLAC' RA=22:02:43.291371 DEC=+42:16:39.97987 equinox='J2000' rem='AGN, rfc_2013d Petrov, 2013, unpublished 59417 observations, RA-AO4-12, RA-AO3-04, RA-AO2-12' /
!
endcat /

! ================================================================ 
! The schedule 
! ================================================================ 
" > re00xx.key

echo "year=$YEAR month=$MONTH day=$DAY start=$STARTTIME
stations=$telescope
setup=$MODE 
record 
 
source = '$SOURCE' prescan = 0 gap = 0 dur = $LENGHT_OF_THE_FIRST_SCAN_SECOND / 
" >> re00xx.key

if [ $NUMBER_OF_SCANS_MINUS_TWO -ge 1 ];then
echo "group 1 rep $NUMBER_OF_SCANS_MINUS_TWO 
 source = '$SOURCE' prescan = 0 gap = 30 dur = 570 /
" >> re00xx.key
fi 

if [ $EXPERIMENT_DURATION_MIN -ge 20 ];then
 echo "source = '$SOURCE' prescan = 0 gap = 30 dur = $LENGHT_OF_THE_LAST_SCAN_SECONDS / 
" >> re00xx.key
fi

# Make a symbolic link to stations.dat since the string $REAL_PATH/$STATIONS_DAT_FILE may be too long for SCHED to handle
ln -s "$REAL_PATH/$STATIONS_DAT_FILE" stations.dat

# Run SCHED
$SCHEDEXECUTABLE < re00xx.key | grep Finished &>/dev/null

 if [ $? -ne 0 ];then
  cd - &> /dev/null
  rm -rf $WORK_DIR &
  exit
 fi

# if [ $? -eq 0 ];then
  # If source is not visible during part of the observation
  grep "$SOURCE" re00xx.sum |grep "-" | awk '{print $6}' | grep "D" &>/dev/null && rm -rf $WORK_DIR && exit
  grep "$SOURCE" re00xx.sum |grep "-" | awk '{print $6}' | grep "H" &>/dev/null && rm -rf $WORK_DIR && exit
  grep "$SOURCE" re00xx.sum |grep "-" | awk '{print $6}' | grep "S" &>/dev/null && rm -rf $WORK_DIR && exit
  grep "$SOURCE" re00xx.sum |grep "-" | awk '{print $6}' | grep "R" &>/dev/null && rm -rf $WORK_DIR && exit
  grep "$SOURCE" re00xx.sum |grep "-" | awk '{print $6}' | grep "W" &>/dev/null && rm -rf $WORK_DIR && exit

  # Get observing time
  observing_time=`grep $telescope re00xx.sum |tail -n1 | awk '{print $3" "$5}'`
  observing_dates=`grep $telescope re00xx.sum |tail -n1 | awk '{print $2" "$4}'`
  observing_date_start=`echo "$observing_dates" | awk '{print $1}'`
  observing_date_stop=`echo "$observing_dates" | awk '{print $2}'`
  # Special case of January 31
  if [ $MONTH -eq 12 ];then
   if [ $DAY -eq 31 ];then
    if [ "$observing_date_start" != "$observing_date_stop" ];then
     observing_date_stop=`echo "$observing_date_start+1"|bc -q`
    fi
   fi
  fi
  observing_date_difference=`echo "$observing_date_stop-$observing_date_start"|bc -q`
  observing_time=`echo ${observing_time//:/ }| awk '{print $1":"$2":"$3"-"$4":"$5":"$6}'`
  observing_time_start="$observing_time"
  observing_time_start=`echo ${observing_time_start//-/ }| awk '{print $1}'`
  observing_time_stop="$observing_time"
  observing_time_stop=`echo ${observing_time_stop//-/ }| awk '{print $2}'`
  observing_time_start_unixsec=`$DATE_EXECUTABLE --utc -d "$YEAR-$MONTH-$DAY  $observing_time_start" +%s`
  observing_time_stop_unixsec=`$DATE_EXECUTABLE --utc -d "$YEAR-$MONTH-$DAY  $observing_time_stop" +%s`
  observing_time_length_sec=`echo "$observing_time_stop_unixsec-$observing_time_start_unixsec+$observing_date_difference*86400"|bc -q`
  
  # If observing time lenght < intended duration of the experiment (default: 3599 sec)
  if [ $observing_time_length_sec -lt $intended_experiment_duration_seconds ];then
   cd - &> /dev/null
   rm -rf $WORK_DIR &
   exit
  fi
  
    
#  echo " $telescope" > $RESULTS_DIR/`tr -cd a-zA-Z0-9 < /dev/urandom | head -c 12 ; echo ""`$$
  echo " $telescope" > $RESULTS_DIR/$FORKED_SESSION_KEY
# fi 

 # You may use re00xx.key as a template
 #cp $WORK_DIR/re00xx.key .
 rm -rf $WORK_DIR &

}
#### END OF FUNCTION TO FORK




# Check if $SCHED variable is set
if [ -z $SCHED ];then
 # No SCHED variable is set, trying to guess
 if [ -d $HOME/sched ];then
  # Trying to find SCHED in the most obvious location
  export SCHED="$HOME/sched"
 else
  echo " ERROR: cannot find SCHED variable in the environment! This variable should point to SCHED installation directory. Please install SCHED." > /dev/stderr
  exit 1
 fi
fi

# Find the SCHED executable
SCHEDEXECUTABLE=`which sched 2>/dev/null`
if [ -z $SCHEDEXECUTABLE ];then
 if [ -x $SCHED/bin/sched ];then
  SCHEDEXECUTABLE=$SCHED/bin/sched
 else
  echo " ERROR: cannot find sched executable! Do you have SCHED installed?" > /dev/stderr
  exit 1
 fi
fi
# export it just in case... we are gonna use it from inside a forked function
export SCHEDEXECUTABLE

if [ ! -z $5 ];then
 YEAR=$1
 MONTH=$2
 DAY=$3
 STARTTIME=$4
 SOURCE=$5
 EXPERIMENT_DURATION_MIN=60
 INPUT_OK=1
fi

if [ ! -z $4 ];then
 if [ $INPUT_OK -eq 0 ];then
  YEAR=`echo $1 | awk '{print $3}' FS='.'`
  MONTH=`echo $1 | awk '{print $2}' FS='.'`
  DAY=`echo $1 | awk '{print $1}' FS='.'`
  STARTTIME=$2
  SOURCE=$3
  EXPERIMENT_DURATION_MIN=$4
  INPUT_OK=1
 fi
fi

if [ ! -z $3 ];then
 if [ $INPUT_OK -eq 0 ];then
  YEAR=`echo $1 | awk '{print $3}' FS='.'`
  MONTH=`echo $1 | awk '{print $2}' FS='.'`
  DAY=`echo $1 | awk '{print $1}' FS='.'`
  STARTTIME=$2
  SOURCE=$3
  EXPERIMENT_DURATION_MIN=60
  INPUT_OK=1
 fi
fi

# Find the GNU date executable: 'date' on Linux, 'gdate' on Mac 
which gdate &>/dev/null
if [ $? -eq 0 ];then
 DATE_EXECUTABLE=gdate
else
 DATE_EXECUTABLE=date
fi

if [ ! -z $1 ];then
 if [ $INPUT_OK -eq 0 ];then

  # Clean-up
  if [ -f $DETAILED_VISIBILITY_PROFILE ];then
   rm -f $DETAILED_VISIBILITY_PROFILE
  fi

  # Automatic schedule parser to make good source names
  RAW_SCHEDULE=$1
  # Check if the schedule file exist
  if [ ! -f $RAW_SCHEDULE ];then
   echo "ERROR: Cannot open schedule file $RAW_SCHEDULE" > /dev/stderr
   exit 1
  fi

  #############################################################
  # Below we handle three possibilities:
  # 1. (default) the supplied file is a block schedule
  # 2. the supplied file is a "Yuri-style request" with UT dates
  # 3. the supplied file is a "NPO-style request" with UT+3h dates
  #############################################################

  # Check if this is a request, not an actual block schedule
  grep "start=" $RAW_SCHEDULE &> /dev/null
  if [ $? -eq 0 ];then
   grep '\[observation\]' $RAW_SCHEDULE &> /dev/null
   if [ $? -eq 0 ];then
    FORMAT="SRTSCHED (time = UT+3h)"
   else
    FORMAT="REQUEST (time = UT)"
   fi
   echo "$FORMAT format detected! Re-formating as block sched..." >> /dev/stderr
   REQUESTFILE=$RAW_SCHEDULE
   grep "start=" $REQUESTFILE |while read STRTLINE ;do
    
    SOURCE=`grep -B1 "$STRTLINE" $REQUESTFILE | head -n1 | awk '{print $1}'`
    # Check if the SOURCE line make sence
    echo "$SOURCE" | grep '\[SNS' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    echo "$SOURCE" | grep 'var0' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    echo "$SOURCE" | grep 'var1' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    echo "$SOURCE" | grep 'var2' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    echo "$SOURCE" | grep 'var3' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    if [ $SOURCE == "HOME" ];then
     # This is a tracking station test, no need to check GRTs
     continue
    fi
    
    echo "Observational code: raks01xz
Proposals: RA-AO1-10; Ef 24-12; Gb 13A-252, 13B-226; Wb R13B015; Ar V2834
Task: AGN Survey"
    if [ "$FORMAT" == "REQUEST (time = UT)" ];then
     # REQUEST format, dates are UT
     echo ${STRTLINE/start=/Start(UT):}
     STOP=`grep -A1 "$STRTLINE" $REQUESTFILE | tail -n1`
     echo ${STOP/stop =/Stop(UT) :}
    else
     # SRTSCHED format, dates are UT+3h
     OBSERVING_TIME=${STRTLINE//start=/}
     START_YEAR=`echo $OBSERVING_TIME | awk '{print $1}' | awk '{print $3}' FS='.'`
     START_MONTH=`echo $OBSERVING_TIME | awk '{print $1}' | awk '{print $2}' FS='.'`
     START_DAY=`echo $OBSERVING_TIME | awk '{print $1}' | awk '{print $1}' FS='.'`
     STARTTIME=`echo $OBSERVING_TIME | awk '{print $2}'`
     START_MSK_UNIXSEC=`$DATE_EXECUTABLE --utc -d "$START_YEAR-$START_MONTH-$START_DAY  $STARTTIME" +%s`
     START_UT_UNIXSEC=`echo "$START_MSK_UNIXSEC-3*3600" |bc -q`
     START_UT_STRING=`$DATE_EXECUTABLE --utc -d "@$START_UT_UNIXSEC" "+%d.%m.%Y %H:%M"`
     START_UT_STRING="Start(UT): $START_UT_STRING"
     
     STOP=`grep -A1 "$STRTLINE" $REQUESTFILE | tail -n1`
     OBSERVING_TIME=${STOP/stop =/}
     STOP_YEAR=`echo $OBSERVING_TIME | awk '{print $1}' | awk '{print $3}' FS='.'`
     STOP_MONTH=`echo $OBSERVING_TIME | awk '{print $1}' | awk '{print $2}' FS='.'`
     STOP_DAY=`echo $OBSERVING_TIME | awk '{print $1}' | awk '{print $1}' FS='.'`
     STOPTIME=`echo $OBSERVING_TIME | awk '{print $2}'`
     #echo "DEBUG #$STOP_DAY# #$STOPTIME#" >> /dev/stderr
     if [ "$STOPTIME" == "24:00:00" ];then
      STOPTIME="23:59:59"
     fi
     STOP_MSK_UNIXSEC=`$DATE_EXECUTABLE --utc -d "$STOP_YEAR-$STOP_MONTH-$STOP_DAY  $STOPTIME" +%s`
     STOP_UT_UNIXSEC=`echo "$STOP_MSK_UNIXSEC-3*3600" |bc -q`
     STOP_UT_STRING=`$DATE_EXECUTABLE --utc -d "@$STOP_UT_UNIXSEC" "+%d.%m.%Y %H:%M"`
     STOP_UT_STRING="Stop(UT) : $STOP_UT_STRING"
     
     echo "$START_UT_STRING
$STOP_UT_STRING"
    fi
    echo "Band: CL
Pcal: ON, noise diode: ON"
#    SOURCE=`grep -B1 "$STRTLINE" $REQUESTFILE | head -n1 | awk '{print $1}'`
    echo "Source: $SOURCE"
    GRT=`grep -A5 "$STRTLINE" $REQUESTFILE | grep GRT | tail -n1`
    echo ${GRT/GRT =/GRT: }
    echo "Comments: 13.1xED  PA=12.1
"
   done > pseudoblocksched.tmp
   RAW_SCHEDULE=pseudoblocksched.tmp
   echo "Done re-formating! The interpreted schedule is written to pseudoblocksched.tmp" >> /dev/stderr
  else  
   # Check if this is a GRT request, not an actual blocak schedule
   TEST=`grep -c "Start(UT):" $RAW_SCHEDULE`
   if [ $TEST -eq 0 ];then
    TEST=`grep -c " UT " $RAW_SCHEDULE`
    if [ $TEST -eq 0 ];then
     echo "This doesn't seem to be a GRT request..." >> /dev/stderr
     exit 1
    fi
    echo "Re-formating as block sched..." >> /dev/stderr
    REQUESTFILE=$RAW_SCHEDULE
    grep " UT" $REQUESTFILE |while read STRTLINE ;do
    
     SOURCE=`grep -A1 "$STRTLINE" $REQUESTFILE | tail -n1 | awk '{print $1}'`
     if [ $SOURCE == "HOME" ];then
      # This is a tracking station test, no need to check GRTs
      continue
     fi
    
     echo "Observational code: raks01xz
Proposals: RA-AO1-10; Ef 24-12; Gb 13A-252, 13B-226; Wb R13B015; Ar V2834
Task: AGN Survey"

     # REQUEST format, dates are UT
     STARTDATE=`echo "$STRTLINE" | awk '{print $1}'`
     STARTTIME=`echo "$STRTLINE" | awk '{print $2}' | awk '{print $1}' FS='-'`
     STOPTIME=`echo "$STRTLINE" | awk '{print $2}' | awk '{print $2}' FS='-'`
     
     STARTDATE_DD=`echo $STARTDATE | awk '{print $1}' FS='.'`
     STARTDATE_MM=`echo $STARTDATE | awk '{print $2}' FS='.'`
     STARTDATE_YYYY=`echo $STARTDATE | awk '{print $3}' FS='.'`
     
     STARTDATE_UNIXSEC=`date -u -d "$STARTDATE_YYYY-$STARTDATE_MM-$STARTDATE_DD $STARTTIME:00" +%s`
     STOPDATE_UNIXSEC=`date -u -d "$STARTDATE_YYYY-$STARTDATE_MM-$STARTDATE_DD $STOPTIME:00" +%s`
     if [ $STOPDATE_UNIXSEC -lt $STARTDATE_UNIXSEC ];then
      STOPDATE_UNIXSEC=`echo "$STOPDATE_UNIXSEC+86400" | bc -q`
      STOPDATE_DD=`date -d @$STOPDATE_UNIXSEC +%d | awk '{printf "%02d", $1}'`
      STOPDATE_MM=`date -d @$STOPDATE_UNIXSEC +%m | awk '{printf "%02d", $1}'`
      STOPDATE_YYYY=`date -d @$STOPDATE_UNIXSEC +%Y`
      STOPDATE="$STOPDATE_DD.$STOPDATE_MM.$STOPDATE_YYYY"
     else
      STOPDATE="$STARTDATE"
     fi

     
     echo "Start(UT): $STARTDATE $STARTTIME:00"
     echo "Stop(UT) : $STOPDATE $STOPTIME:00"

     echo "Band: CL
Pcal: ON, noise diode: ON"
     echo "Source: $SOURCE"
     #GRT=`grep -A5 "$STRTLINE" $REQUESTFILE | grep GRT | tail -n1`
     GRT=`grep -A2 "$STRTLINE" $REQUESTFILE | tail -n1`
     echo "GRT: $GRT"
     echo "Comments: 13.1xED  PA=12.1
"
    done > pseudoblocksched.tmp
    #
    echo "########################################" >> /dev/stderr
    #cat pseudoblocksched.tmp >> /dev/stderr
    #
    RAW_SCHEDULE=pseudoblocksched.tmp
    echo "Done re-formating! The interpreted schedule is written to pseudoblocksched.tmp" >> /dev/stderr
   fi
  fi # SRT blocak sched or not

  echo "$0 is processing the schedule..." >> /dev/stderr

  rm -f processed_schedule.tmp
  cat $RAW_SCHEDULE | while read STR ;do
   FIRST_ITEM=`echo "$STR" | awk '{print $1}'`
   if [ "$FIRST_ITEM" == "Source:" ];then
    TARGET_SOURCE=${STR//"Source: "/}
    # Try to guess if this is a propper source name and its alias.
    # Here we assume that a propper source name would contain a "+" or "-" sign.
    if [[ "$TARGET_SOURCE" == *"+"* ]];then
     TARGET_SOURCE=`echo "$TARGET_SOURCE" | awk '{print $1}' FS=' '`
    fi
    if [[ "$TARGET_SOURCE" == *"-"* ]];then
     TARGET_SOURCE=`echo "$TARGET_SOURCE" | awk '{print $1}' FS=' '`
    fi
    # Remove white spaces from the source name
    TARGET_SOURCE=${TARGET_SOURCE//" "/""}
    # Make the source name uppercase
    TARGET_SOURCE=${TARGET_SOURCE^^}
    # Remove source alias if the alias is iside brackets
    TARGET_SOURCE=`echo "$TARGET_SOURCE" | awk '{print $1}' FS='('`
    # Remove coma from the source name
    TARGET_SOURCE=`echo "$TARGET_SOURCE" | awk '{print $1}' FS=','`
    STR="Source: $TARGET_SOURCE"
   fi
   # If the string does not contain the comment sign...
   echo "$STR" | grep "#" &>/dev/null
   if [ $? -ne 0 ];then
    echo "$STR" | sed 's:\r::g' >> processed_schedule.tmp
    #ls processed_schedule.tmp >> /dev/stderr
    #echo $PWD >> /dev/stderr
    #echo "$STR" | sed 's:\r::g' >> /dev/stderr
   fi
  done
  SCHEDULE_FILE=processed_schedule.tmp
  
  if [ ! -f $SCHEDULE_FILE ];then
   echo "ERROR: cannot find $SCHEDULE_FILE" >> /dev/stderr
   exit 1
  fi
  
  # By default, assume the schedule is OK
  rm -f problem_with_the_schedule.tmp
  
  # Check each experiment
  grep "Start(UT)" $SCHEDULE_FILE |grep -v Commen | while read STR ;do
   
   # $START_UT_STRING_FOR_GREP will be used to identify the experiment and parse its
   # description further in the scrip
   START_UT_STRING_FOR_GREP=$STR
   
   ### ***** GET EXPERIMENT DURATION ***** ###
   # Get start time
   # The following will make sure we dont care of '=' or ':' after "Start(UT)" and "Stop(UT) "
   STR=${STR//'='/':'}
   OBSERVING_TIME=${STR//"Start(UT): "/}
   YEAR=`echo $OBSERVING_TIME | awk '{print $1}' | awk '{print $3}' FS='.'`
   MONTH=`echo $OBSERVING_TIME | awk '{print $1}' | awk '{print $2}' FS='.'`
   DAY=`echo $OBSERVING_TIME | awk '{print $1}' | awk '{print $1}' FS='.'`
   STARTTIME=`echo $OBSERVING_TIME | awk '{print $2}'`
   observing_time_start_unixsec=`$DATE_EXECUTABLE --utc -d "$YEAR-$MONTH-$DAY  $STARTTIME" +%s`
   #echo "$DATE_EXECUTABLE --utc -d "$YEAR-$MONTH-$DAY  $STARTTIME" +%s" > /dev/stderr
   # Get stop time
   #OBSERVING_TIME_STOP=`grep -A1 "$OBSERVING_TIME" $SCHEDULE_FILE | tail -n1`
   OBSERVING_TIME_STOP=`grep -A1 "$START_UT_STRING_FOR_GREP" $SCHEDULE_FILE | tail -n1`
   OBSERVING_TIME_STOP=${OBSERVING_TIME_STOP//"="/":"}
   OBSERVING_TIME_STOP=${OBSERVING_TIME_STOP//"Stop(UT) : "/}
   OBSERVING_TIME_STOP=${OBSERVING_TIME_STOP//"Stop (UT): "/}
   YEAR=`echo $OBSERVING_TIME_STOP | awk '{print $1}' | awk '{print $3}' FS='.'`
   MONTH=`echo $OBSERVING_TIME_STOP | awk '{print $1}' | awk '{print $2}' FS='.'`
   DAY=`echo $OBSERVING_TIME_STOP | awk '{print $1}' | awk '{print $1}' FS='.'`
   STOPTIME=`echo $OBSERVING_TIME_STOP | awk '{print $2}'`
   ## Dirty trick
   #STOPTIME=${STOPTIME//24:00/00:00}
   ##
   observing_time_stop_unixsec=`$DATE_EXECUTABLE --utc -d "$YEAR-$MONTH-$DAY  $STOPTIME" +%s`
   observing_time_length_sec=`echo "$observing_time_stop_unixsec-$observing_time_start_unixsec"|bc -q`
   if [ $observing_time_length_sec -le 0 ];then
    echo "Sorry, OBSERVING DATE PROBLEM. Experiment duration $observing_time_stop_unixsec-$observing_time_start_unixsec=$observing_time_length_sec<0
The offending experiment starts at $START_UT_STRING_FOR_GREP"
    exit 1
   fi
   if [ $observing_time_length_sec -gt 86400 ];then
    echo "Sorry, POTENTIAL OBSERVING DATE PROBLEM. Experiment duration $observing_time_stop_unixsec-$observing_time_start_unixsec=$observing_time_length_sec>1 day
The offending experiment starts at $START_UT_STRING_FOR_GREP"
    exit 1
   fi
   EXPERIMENT_DURATION_MIN=`echo "$observing_time_length_sec/60"|bc -q`
   
   ### ***** GET OTHER DETAILS ***** ###
   #SOURCE=`grep -A7 "$OBSERVING_TIME" $SCHEDULE_FILE |grep "Source:" | head -n1`
   SOURCE=`grep -B3 -A7 "$START_UT_STRING_FOR_GREP" $SCHEDULE_FILE |grep "Source:" | head -n1`
   SOURCE=${SOURCE//"Source: "/}
   # Thenk you Jenya...
   if [ "$SOURCE" == "" ];then
    # Fallback to Jenya's format: Source name before "Start(UT)"
    #SOURCE=`grep -B1 "$OBSERVING_TIME" $SCHEDULE_FILE | head -n1`
    SOURCE=`grep -B1 "$START_UT_STRING_FOR_GREP" $SCHEDULE_FILE | head -n1`
   fi
   if [ "$SOURCE" == "" ];then
    echo "Error! Cannot parse the input schedule to extract the source name!" > /dev/stderr
    exit 1
   fi

   # Try to guess if this is a propper source name and its alias.
   # Here we assume that a propper source name would contain a "+" or "-" sign.
   if [[ "$SOURCE" == *"+"* ]];then
    SOURCE=`echo "$SOURCE" | awk '{print $1}' FS=' '`
   fi
   if [[ "$SOURCE" == *"-"* ]];then
    SOURCE=`echo "$SOURCE" | awk '{print $1}' FS=' '`
   fi
   # Remove white spaces from the source name
   SOURCE=${SOURCE//" "/""}    
   # Make the source name uppercase
   SOURCE=${SOURCE^^}
   # Remove source alias if the alias is iside brackets
   SOURCE=`echo "$SOURCE" | awk '{print $1}' FS='('`

   ### Skip HOME
   if [ "$SOURCE" == "HOME" ];then
    echo "Skipping source visibility check for the source HOME..." >> /dev/stderr
    continue
   fi

   
   # Try to get expcode
   EXPCODE=`grep -B4 -A4 "$START_UT_STRING_FOR_GREP" $SCHEDULE_FILE | grep "Observational code:" | tail -n1 | awk '{print $3}'`
   
   # Get bands
   BAND=`grep -A4 "$START_UT_STRING_FOR_GREP" $SCHEDULE_FILE | grep "Band:" | tail -n1 | awk '{print $2}'`
   BAND_1=`expr substr "$BAND" 1 1`
   case "$BAND_1" in
    "K")
    ;;
    "C")
    ;;
    "L")
    ;;
    "P")
    ;;
    *)
    echo "ERROR: unknown BAND_1=$BAND_1" >> /dev/stderr
    exit 1
    ;;
   esac
   BAND_2=`expr substr "$BAND" 2 1`
   case "$BAND_2" in
    "K")
    ;;
    "C")
    ;;  
    "L")
    ;;
    "P")
    ;;
    *)
    echo "ERROR: unknown BAND_2=$BAND_2" >> /dev/stderr
    exit 1
    ;;
   esac

   #echo "$BAND $BAND_1 $BAND_2" >> /dev/stderr


   ########################
   #FAKERAD_TELESCOPES=`grep -A7 "$OBSERVING_TIME" $SCHEDULE_FILE |grep "GRT:" | head -n1`
   FAKERAD_TELESCOPES=`grep -A7 "$START_UT_STRING_FOR_GREP" $SCHEDULE_FILE |grep "GRT" | head -n1`
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"GRT="/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"GRT:"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//,/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"?"/}
   
   FAKERAD_TELESCOPES="${FAKERAD_TELESCOPES//()/($BAND_1$BAND_2)}"
   
   # INSERT
   FAKERAD_TELESCOPES_WITH_BANDS="$FAKERAD_TELESCOPES"
   # END OF INSERT
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(PL)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(LP)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(PC)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(CP)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(PK)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(KP)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(KL)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(LK)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(CL)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(LC)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(KC)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(CK)"/}
   #
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(L)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(C)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(K)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(P)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(P)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(C->K)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(K->C)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(C->L)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(L->C)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(K->L)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(L->K)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(P->L)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(L->P)"/}
   #
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(X)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(U)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(U->X)"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"(X->U)"/}
   #
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"("/" "}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//")"/" "}
   #
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"+"/}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"-"/}
   #echo "$0 $OBSERVING_TIME $SOURCE $EXPERIMENT_DURATION_MIN" > /dev/stderr
   SCHED_TELESCOPES=`$0 $OBSERVING_TIME $SOURCE $EXPERIMENT_DURATION_MIN 2>/dev/stderr`
   echo "$OBSERVING_TIME $SOURCE  $EXPCODE  $SCHED_TELESCOPES" >> $DETAILED_VISIBILITY_PROFILE
   ###
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"Jb1"/"Jb"}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"Jb2"/"Jb"}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"Y27"/"Y"}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"Wb1"/"Wb"}
   ###
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"T6"/"Tm"}
   ###
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"On85"/"On"}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"On60"/"On"}
   ###
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"Ro70"/"Ro"}
   ###
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"Eu"/"Ev"}
   ###
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"VLBA"/"Pt Kp La Br Fd Sc Nl Ov Mk Hn"}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"LBA"/"Pa At Td Mp Ho Cd Hh Ww Ak"}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"KVN"/"Ky Ku Kt"}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"EVN"/"Ef Wb Jb Mc Nt Ys On Mh Tr Sv Zc Bd Ur Sh "}
   FAKERAD_TELESCOPES=${FAKERAD_TELESCOPES//"ATCA"/"At"}
   #echo FAKERAD_TELESCOPES=$FAKERAD_TELESCOPES >> /dev/stderr
   #exit # !!!!

   # See if we can check observing bands
   # CHECK_OBSERVING_BANDS = 1 - yes, 0 - no
   CHECK_OBSERVING_BANDS=1
   echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "($BAND_1" &>/dev/null
   if [ $? -ne 0 ];then
    #echo "The telescopes line ($FAKERAD_TELESCOPES_WITH_BANDS) does not seem to contain information about observing bands! Skipping the band check." >> /dev/stderr
    CHECK_OBSERVING_BANDS=0
   fi
   echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "($BAND_2" &>/dev/null
   if [ $? -ne 0 ];then
    #echo "The telescopes line ($FAKERAD_TELESCOPES_WITH_BANDS) does not seem to contain information about observing bands! Skipping the band check." >> /dev/stderr
    CHECK_OBSERVING_BANDS=0
   fi

   for i in $FAKERAD_TELESCOPES ;do
    #echo "DEBUG: FAKERAD_TELESCOPES=#$FAKERAD_TELESCOPES#"
    
    # Try to avoid telescope names that are not actually telescope names
    echo "$i" | grep 'P:' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    echo "$i" | grep 'L:' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    echo "$i" | grep 'C:' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    echo "$i" | grep 'K:' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    #
    echo "$i" | grep 'PP' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    echo "$i" | grep 'LL' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    echo "$i" | grep 'KK' &> /dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    #    
    if [ "$i" == "P" ];then
     continue
    fi
    if [ "$i" == "L" ];then
     continue
    fi
    if [ "$i" == "C" ];then
     continue
    fi
    if [ "$i" == "K" ];then
     continue
    fi
    #
    # Make sure telescope's name does not contain ':'
    echo "$i" | grep ':' &>/dev/null
    if [ $? -eq 0 ];then
     continue
    fi
    # Make sure telescope's name is not longer than 3 characters
    if [ ${#i} -gt 3 ];then
     echo "$OBSERVING_TIME $SOURCE   $i <-- UNRECOGNIZED TELESCOPE NAME LONGER THAN 3 CHARACTERS"
     continue
    fi
    # Special case of "Eb" = "Ef"
    if [ "$i" == "Eb" ];then
     i="Ef"
    fi
    # Special case of "Y27" = "Y"
    if [ "$i" == "Y27" ];then
     i="Y"
    fi



    # Check if the requested telescope is among those that can observe according to SCHED
    TELESCOPE_OK=0
    for j in $SCHED_TELESCOPES ;do
     if [ "$j" == "$i" ];then
      TELESCOPE_OK=1
      break
     fi
    done
    if [ $TELESCOPE_OK -eq 0 ];then
     echo "$OBSERVING_TIME $SOURCE   $i <-- VISIBILITY NOT OK"
     touch problem_with_the_schedule.tmp
     continue
    fi
    
    # See if we should skip the following observing bands check
    if [ $CHECK_OBSERVING_BANDS -eq 0 ];then
     continue
    fi

    #### Check band consistency
    # by default we are not OK
    BAND_CONSISTENCY_OK=0
    if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "$i($BAND_1" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
    if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "$i($BAND_2" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
    if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "$i($BAND_1->$BAND_2)" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
    if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "$i($BAND_2->$BAND_1)" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
    if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "$i($BAND_1$BAND_2)" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
    if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "$i($BAND_2$BAND_1)" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
    #
    if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "${i/Jb/Jb1}($BAND_1" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
    if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "${i/Jb/Jb2}($BAND_2" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
    if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "${i/Tm/T6}($BAND_1" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
    if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "${i/Tm/T6}($BAND_2" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi    
    #
    if [ "$i" == "On" ];then
     if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "${i/On/On60}($BAND_1" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
     if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "${i/On/On60}($BAND_2" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
     if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "${i/On/On85}($BAND_1" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
     if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "${i/On/On85}($BAND_2" >/dev/null ;then BAND_CONSISTENCY_OK=1 ;fi
    fi
    ##################################
    # Check if an arbitrary number in the range 1 - 100 is added to the telescope name
    # Yes, names like Wb1 and On85 are so coooool...
    for SILLY_NUMBER in `seq 1 100` ;do
     if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "${i/$i/$i$SILLY_NUMBER}($BAND_1" >/dev/null ;then BAND_CONSISTENCY_OK=1 ; break ;fi
     if echo "$FAKERAD_TELESCOPES_WITH_BANDS" | grep "${i/$i/$i$SILLY_NUMBER}($BAND_2" >/dev/null ;then BAND_CONSISTENCY_OK=1 ; break ;fi
    done
    ##################################
    #
    if [ $BAND_CONSISTENCY_OK -eq 0 ];then
     echo "$OBSERVING_TIME $SOURCE   $i <-- OBSERVING BAND PROBLEM! Expected bands: $BAND_1$BAND_2 Telescopes string: $FAKERAD_TELESCOPES_WITH_BANDS"
    fi
    ####

   done
  done
  # Report a problem if there is one
  echo "----------------------------------------------------" > /dev/stderr
  if [ -f problem_with_the_schedule.tmp ];then
   echo "It seems there was a problem with the schedule... :(" > /dev/stderr
  else
   echo "It seems the schedule is Ok... :)" > /dev/stderr
  fi
  echo "A detailed visibility profile for this schedule may be found in $DETAILED_VISIBILITY_PROFILE" > /dev/stderr
  rm -f processed_schedule.tmp
  exit
 fi
fi


# Check format of dates
YEAR=`echo $YEAR | awk '{printf "%04d",$1}'`
MONTH=`echo $MONTH | awk '{printf "%02d",$1}'`
DAY=`echo $DAY | awk '{printf "%02d",$1}'`

# Check if seconds are supplied
START_HH=`echo "$STARTTIME" | awk '{printf "%02d", $1}' FS=':'`
START_MM=`echo "$STARTTIME" | awk '{printf "%02d", $2}' FS=':'`
START_SS=`echo "$STARTTIME" | awk '{print $3}' FS=':'`
if [ ! -z $START_SS ];then
 START_SS="00"
fi
STARTTIME=`echo "$START_HH $START_MM $START_SS" | awk '{printf "%02d:%02d:%02d",$1,$2,$3}'`

# Check if the input is Ok
if [ $INPUT_OK -eq 0 ];then
 echo "Usage: $0 31.12.2012 21:20:00 0133+476 40
 # DATE TIME SOURCE EXPERIMENT_DURATION_MINUTES
 or
 $0 31.12.2012 21:20:00 0133+476
 or
 $0 2012 12 31 21:20 0133+476"  > /dev/stderr
 exit 1
fi

######
#echo DEBUG: $0 $1 $2 $3 $4 $5 $6 $7 $8 $9 >> /dev/stderr
######

#
###############################################
# Check the input

if [ -z $YEAR ];then
 echo "Please set year!" > /dev/stderr
 exit 1
fi
if [ -z $MONTH ];then
 echo "Please set month!" > /dev/stderr
 exit 1
fi
if [ -z $DAY ];then
 echo "Please set day!" > /dev/stderr
 exit 1
fi
if [ -z $STARTTIME ];then
 echo "Please set start time!" > /dev/stderr
 exit 1
fi
if [ -z $SOURCE ];then
 echo "Please set the source name!" > /dev/stderr
 exit 1
fi

#echo "Input parameters:  YEAR=$YEAR MONTH=$MONTH DAY=$DAY STARTTIME=$STARTTIME SOURCE=$SOURCE EXPERIMENT_DURATION_MIN=$EXPERIMENT_DURATION_MIN" > /dev/stderr
###############################################



# Compute the intended experiment duration in seconds
intended_experiment_duration_seconds=`echo "$EXPERIMENT_DURATION_MIN*60-1" |bc -q`
# We want one second to spare if the exparement ends at 23:59:59

# Make sure we don't loose a 10 minute scan because of one minute
if [ $EXPERIMENT_DURATION_MIN -eq 59 ];then
 EXPERIMENT_DURATION_MIN=60
elif [ $EXPERIMENT_DURATION_MIN -eq 49 ];then
 EXPERIMENT_DURATION_MIN=50
elif [ $EXPERIMENT_DURATION_MIN -eq 39 ];then
 EXPERIMENT_DURATION_MIN=40
elif [ $EXPERIMENT_DURATION_MIN -eq 29 ];then
 EXPERIMENT_DURATION_MIN=20
fi

### NOW, the new trick: choose the length of the last scan
LENGHT_OF_THE_LAST_SCAN_SECONDS=`echo "600+${EXPERIMENT_DURATION_MIN: (-1)}*60" |bc -q`
LENGHT_OF_THE_FIRST_SCAN_SECOND=570
if [ $EXPERIMENT_DURATION_MIN -lt 20 ];then
 LENGHT_OF_THE_FIRST_SCAN_SECOND=`echo "$EXPERIMENT_DURATION_MIN*60" | bc -q`
fi

## Make sure the experiment duration is a multiple of 10'
#if [ ${EXPERIMENT_DURATION_MIN:(-1)} -ne 0 ];then
# echo "ERROR: the experiment duration sould be a multiple of 10 minutes:
#40 minutes - good, 45 minutes - not good." >/dev/stderr
# exit 1
#fi

# Compute the number of 10' scans
NUMBER_OF_SCANS_MINUS_TWO=`echo "$EXPERIMENT_DURATION_MIN/10-2" |bc -q`
#echo "EXPERIMENT_DURATION_MIN=$EXPERIMENT_DURATION_MIN  NUMBER_OF_SCANS_MINUS_TWO=$NUMBER_OF_SCANS_MINUS_TWO" > /dev/stderr
if [ $NUMBER_OF_SCANS_MINUS_TWO -lt -1 ] ;then
 if [ $EXPERIMENT_DURATION_MIN -lt 1 ];then
  echo "Error: unsupported observation length! Please try observation length of 1, 2, 5, 10, 20, 40, 60 minutes..." > /dev/stderr
  exit 1
 fi
# if [ $EXPERIMENT_DURATION_MIN -gt 10 ];then
#  echo "Error: unsupported observation length! Please try 5, 10, 20, 40, 60 minutes..." > /dev/stderr
#  exit 1
# fi
fi


## Make SOURCE uppercase
SOURCE=${SOURCE^^}
## Special case of BL-LAC
if [ "$SOURCE" == "BL-LAC" ];then
 SOURCE="BLLAC"
fi
## Special case of SNS_LL
echo "$SOURCE" | grep "SNS_LL" &> /dev/null
if [ $? -eq 0 ];then
 # This is a laser ranging session, not a source
 exit
fi

# Check if SCHED knows the source
grep --ignore-case \'$SOURCE\' $SCHED/catalogs/sources.vlba &> /dev/null
if [ $? -ne 0 ];then
 # Source not found in the SCHED's catalog
 # Maybe it is in the script's internal catalog?
 grep -v \! $0 | grep --ignore-case \'$SOURCE\' &> /dev/null
 if [ $? -ne 0 ];then
  # Source was not found, report the problem
  echo "ERROR: source \"$SOURCE\" not found!" > /dev/stderr
  # Now try to suggest a solution
  GUESSED_SOURCE_NAME_FOUND=0

  # Now try the few obvious source name modification
  GUESSED_SOURCE_NAME="$SOURCE"_H2O
  grep -v \! $0 | grep --ignore-case \'$GUESSED_SOURCE_NAME\' &> /dev/null
  if [ $? -eq 0 ];then
   echo "Did you mean \"$GUESSED_SOURCE_NAME\"?" > /dev/stderr
   GUESSED_SOURCE_NAME_FOUND=1
  fi
  
  GUESSED_SOURCE_NAME=${SOURCE//"_H2O"/}
  grep -v \! $0 | grep --ignore-case \'$GUESSED_SOURCE_NAME\' &> /dev/null
  if [ $? -eq 0 ];then
   echo "Did you mean \"$GUESSED_SOURCE_NAME\"?" > /dev/stderr
   GUESSED_SOURCE_NAME_FOUND=1
  fi
  
  GUESSED_SOURCE_NAME="$SOURCE"_OH
  grep -v \! $0 | grep --ignore-case \'$GUESSED_SOURCE_NAME\' &> /dev/null
  if [ $? -eq 0 ];then
   echo "Did you mean \"$GUESSED_SOURCE_NAME\"?" > /dev/stderr
   GUESSED_SOURCE_NAME_FOUND=1
  fi
  
  GUESSED_SOURCE_NAME=${SOURCE//"_OH"/}
  grep -v \! $0 | grep --ignore-case \'$GUESSED_SOURCE_NAME\' &> /dev/null
  if [ $? -eq 0 ];then
   echo "Did you mean \"$GUESSED_SOURCE_NAME\"?" > /dev/stderr
   GUESSED_SOURCE_NAME_FOUND=1
  fi
  

  # If no good names were found, just tell the user to hack off
  if [ $GUESSED_SOURCE_NAME_FOUND -eq 0 ];then
   echo "Please add the source to the catalog inside the body of the script: $0" > /dev/stderr
  fi
  exit 1
 fi
fi


## !!! Special trap to work with ./draft.sh
#if [ -f sched_visibility_test/stations.dat ];then
# STATIONS_DAT_FILE="sched_visibility_test/stations.dat"
#fi

# If there is no local copy of stations.dat
if [ ! -f $REAL_PATH/$STATIONS_DAT_FILE ];then
 echo "WARNING: cannot find stations.dat file! Thrying to download one..." > /dev/stderr
 wget -O $REAL_PATH/$STATIONS_DAT_FILE "ftp://grt:K0&th%@webinet.asc.rssi.ru/schedule/grtsched/RAES/rk01aa/stations.dat" &>/dev/stderr
fi

# If there is no local copy of stations.dat and we couldn't download it
if [ ! -f $REAL_PATH/$STATIONS_DAT_FILE ];then
 echo "WARNING: no custom-made stations.dat file is found in "`dirname $0`" This means the script cannot check the funny antennas EVPATORI and USUDARA" > /dev/stderr
 cp $SCHED/catalogs/stations.dat $REAL_PATH/$STATIONS_DAT_FILE
fi

# If still there is no file
if [ ! -f $REAL_PATH/$STATIONS_DAT_FILE ];then
 echo "ERROR! Cannot find stations.dat" > /dev/stderr
 exit 1
fi

# Go!
telescopes=""
#for telescope in ARECIBO ;do
for telescope in SVETLOE ZELENCHK BADARY EVPATORI EFLSBERG GBT_VLBA WSTRBORK MEDICINA NOTO YEBES40M TORUN HART JODRELL1 SHANGHAI SHAO-65 URUMQI ONSALA85 METSAHOV USUDARA DSS63 ATCA MOPRA HOBART CEDUNA PARKES DSS43 VLBA_PT VLBA_KP VLBA_LA VLBA_BR VLBA_FD VLBA_SC VLBA_NL VLBA_OV VLBA_MK VLBA_HN VLA27 ARECIBO KVNYS KVNUS KVNTN KALYAZIN SARDINIA ASKAP KASHIM34 IRBENE ;do
 # just in case
 #export telescope=$telescope

 # Default settings
 FREQREF_K="22236.00"
 FREQREF_C="4836.00"
 FREQREF_L="1668.00"
 PCAL_MHZ="1MHz"
 NOISE_DIODE="ON"

 # Default mode
 MODE="ra6cm2.set"
 NETSIDE_LINE="  netside = L, L, U, U"
 # Modes for special telescopes that do not work in the default mode
 if [ "$telescope" == "DSS63" ];then
  MODE="ra1cm2.set"
 elif [ "$telescope" == "DSS43" ];then
  MODE="ra1cm2.set"
 #elif [ "$telescope" == "DSS14" ];then
 # MODE="ra1cm2.set"
 elif [ "$telescope" == "METSAHOV" ];then
  MODE="ra1cm2.set"
 elif [ "$telescope" == "VLA27" ];then
  MODE="ra1cm2.set"
  # A different netside line is needed to trick the VLA
  NETSIDE_LINE="  netside = U, U"
 elif [ "$telescope" == "KVNYS" ];then
  MODE="ra1cm2.set"
 elif [ "$telescope" == "KVNUS" ];then
  MODE="ra1cm2.set"
 elif [ "$telescope" == "KVNTN" ];then
  MODE="ra1cm2.set"
 #elif [ "$telescope" == "WW_LBA" ];then
 # MODE="ra18cm2.set"
 elif [ "$telescope" == "ASKAP" ];then
  MODE="ra18cm2.set"
 elif [ "$telescope" == "JODRELL1" ];then
  MODE="ra18cm2.set"
 elif [ "$telescope" == "SARDINIA" ];then
  MODE="ra18cm2.set"
 fi

############

 # Go multithread
 #echo $telescope >> /dev/stderr
 function_to_fork &
 PIDS="$PIDS $! "
 NPROC=$[$NPROC+1]
 while [ $NPROC -gt $[$NUMBER_OF_THREADS-1] ] ;do
  # check each running process
  #echo "$PIDS"
  for PID in $PIDS ;do
   ps -p $PID &> /dev/null
   if [ $? -ne 0 ];then   
    PIDS=${PIDS/" $PID "/}
    NPROC=$[$NPROC-1]
   fi
  done
  sleep 0.01
 done
 # Now we are sure no more than NUMBER_OF_THREADS procssess are runnning
 #echo "$PIDS" > /tmp/autosched_"$$"_pids.tmp
 echo "$PIDS" > /tmp/autosched_"$SESSION_KEY"_pids.tmp

done

# Wait for the remeining processes to finish
#for PID in `cat /tmp/autosched_"$$"_pids.tmp` ;do
for PID in `cat /tmp/autosched_"$SESSION_KEY"_pids.tmp` ;do
 while true ;do
  ps -p $PID &> /dev/null
  if [ $? -ne 0 ];then   
   break
  fi
  sleep 0.01
 done
done 
# In case something above fails...
wait
#rm -f /tmp/autosched_"$$"_pids.tmp &
rm -f /tmp/autosched_"$SESSION_KEY"_pids.tmp &


#echo "$telescopes"
if [ "$(ls -A $RESULTS_DIR)" ]; then
 cat $RESULTS_DIR/* | sort > $RESULTS_DIR.tmp 
else
 echo "NO_TELESCOPES" | sort > $RESULTS_DIR.tmp
fi

while read telescope ;do
  #
  short_telescope=""
  if [ "$telescope" == "SVETLOE" ];then
   short_telescope="Sv"
  elif [ "$telescope" == "ZELENCHK" ];then
   short_telescope="Zc"
  elif [ "$telescope" == "BADARY" ];then
   short_telescope="Bd"
  elif [ "$telescope" == "EVPATORI" ];then
   short_telescope="Ev"
  elif [ "$telescope" == "KALYAZIN" ];then
   short_telescope="Kl"
  elif [ "$telescope" == "EFLSBERG" ];then
   short_telescope="Ef"
  elif [ "$telescope" == "GBT_VLBA" ];then
   short_telescope="Gb"
  #elif [ "$telescope" == "GBT_COLD" ];then
  # short_telescope="Gb"
  elif [ "$telescope" == "WSTRBORK" ];then
   short_telescope="Wb"
  elif [ "$telescope" == "MEDICINA" ];then
   short_telescope="Mc"
  elif [ "$telescope" == "NOTO" ];then
   short_telescope="Nt"
  elif [ "$telescope" == "YEBES40M" ];then
   short_telescope="Ys"
  elif [ "$telescope" == "JODRELL1" ];then
   short_telescope="Jb"
  elif [ "$telescope" == "SHANGHAI" ];then
   short_telescope="Sh"
  elif [ "$telescope" == "SHAO-65" ];then
   short_telescope="Tm"
  elif [ "$telescope" == "URUMQI" ];then
   short_telescope="Ur"
  elif [ "$telescope" == "TORUN" ];then
   short_telescope="Tr"
  elif [ "$telescope" == "ONSALA85" ];then
   short_telescope="On"
  elif [ "$telescope" == "METSAHOV" ];then
   short_telescope="Mh"
  elif [ "$telescope" == "ARECIBO" ];then
   short_telescope="Ar"
  elif [ "$telescope" == "USUDARA" ];then
   short_telescope="Ud"
  elif [ "$telescope" == "DSS63" ];then
   short_telescope="Ro"
  elif [ "$telescope" == "ATCA" ];then
   short_telescope="At"
  elif [ "$telescope" == "CEDUNA" ];then
   short_telescope="Cd"
  elif [ "$telescope" == "DSS43" ];then
   short_telescope="Td"
  #elif [ "$telescope" == "DSS14" ];then
  # short_telescope="Go"
  elif [ "$telescope" == "ASKAP" ];then
   short_telescope="Ak"
  #elif [ "$telescope" == "WW_LBA" ];then
  # short_telescope="Ww"
  elif [ "$telescope" == "HART" ];then
   short_telescope="Hh"
  elif [ "$telescope" == "HOBART" ];then
   short_telescope="Ho"
  elif [ "$telescope" == "MOPRA" ];then
   short_telescope="Mp"
  elif [ "$telescope" == "PARKES" ];then
   short_telescope="Pa"
  elif [ "$telescope" == "VLBA_PT" ];then
   short_telescope="Pt"
  elif [ "$telescope" == "VLBA_KP" ];then
   short_telescope="Kp"
  elif [ "$telescope" == "VLBA_LA" ];then
   short_telescope="La"
  elif [ "$telescope" == "VLBA_BR" ];then
   short_telescope="Br"
  elif [ "$telescope" == "VLBA_FD" ];then
   short_telescope="Fd"
  elif [ "$telescope" == "VLBA_SC" ];then
   short_telescope="Sc"
  elif [ "$telescope" == "VLBA_NL" ];then
   short_telescope="Nl"
  elif [ "$telescope" == "VLBA_OV" ];then
   short_telescope="Ov"
  elif [ "$telescope" == "VLBA_MK" ];then
   short_telescope="Mk"
  elif [ "$telescope" == "VLBA_HN" ];then
   short_telescope="Hn"
  elif [ "$telescope" == "VLA27" ];then
   short_telescope="Y"
  elif [ "$telescope" == "KVNYS" ];then
   short_telescope="Ky"
  elif [ "$telescope" == "KVNUS" ];then
   short_telescope="Ku"
  elif [ "$telescope" == "KVNTN" ];then
   short_telescope="Kt"
  elif [ "$telescope" == "SARDINIA" ];then
   short_telescope="Sr"
  elif [ "$telescope" == "KASHIM34" ];then
   short_telescope="Ks"
  elif [ "$telescope" == "IRBENE" ];then
   short_telescope="Ir"
  else
   short_telescope="$telescope"
  fi
 echo -n " $short_telescope" 
done < $RESULTS_DIR.tmp
echo ""

rm -rf $RESULTS_DIR $RESULTS_DIR.tmp 

